Welcome to nandist's documentation!
===================================

``nandist`` is a drop-in replacement for distance calculating functions from ``scipy.spatial.distance`` that works
when the arrays you want to calculate distances between have missing data (NaNs) in them.

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: General

   quickstart.rst
   support.rst
   testing.rst

.. toctree::
   :maxdepth: 2
   :caption: How it works
   :hidden:

   corrections.rst

.. toctree::
   :maxdepth: 2
   :caption: API reference
   :hidden:

   apiref.rst
